@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 Jeremy Lainé
+ * Copyright (C) 2010-2015 Jeremy Lainé
  * Contact: https://github.com/jlaine/qdjango
  *
  * This file is part of the QDjango Library.
@@ -419,6 +419,8 @@ QDjangoMetaModel& QDjangoMetaModel::operator=(const QDjangoMetaModel& other)
 
 /*!
     Creates the database table for this QDjangoMetaModel.
+
+    \return true if the table was created, false otherwise.
 */
 bool QDjangoMetaModel::createTable() const
 {
@@ -642,10 +644,14 @@ QStringList QDjangoMetaModel::createTableSql() const
 
 /*!
     Drops the database table for this QDjangoMetaModel.
+
+    \return true if the table was dropped or did not exist, false otherwise.
 */
 bool QDjangoMetaModel::dropTable() const
 {
     QSqlDatabase db = QDjango::database();
+    if (!db.tables().contains(d->table))
+        return true;
 
     QDjangoQuery query(db);
     return query.exec(QLatin1String("DROP TABLE ") +
