@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 Jeremy Lainé
+ * Copyright (C) 2010-2015 Jeremy Lainé
  * Contact: https://github.com/jlaine/qdjango
  *
  * This file is part of the QDjango Library.
@@ -31,7 +31,7 @@ class QDjangoMetaModelPrivate;
  *
  * \internal
  */
-class QDJANGO_EXPORT QDjangoMetaField
+class QDJANGO_DB_EXPORT QDjangoMetaField
 {
 public:
     QDjangoMetaField();
@@ -61,7 +61,7 @@ private:
  *
  * \internal
  */
-class QDJANGO_EXPORT QDjangoMetaModel
+class QDJANGO_DB_EXPORT QDjangoMetaModel
 {
 public:
     QDjangoMetaModel(const QMetaObject *model = 0);
