@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 Jeremy Lainé
+ * Copyright (C) 2010-2015 Jeremy Lainé
  * Contact: https://github.com/jlaine/qdjango
  *
  * This file is part of the QDjango Library.
@@ -75,7 +75,7 @@
  *
  * \ingroup Database
  */
-class QDJANGO_EXPORT QDjangoModel : public QObject
+class QDJANGO_DB_EXPORT QDjangoModel : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(QVariant pk READ pk WRITE setPk)
