@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 Jeremy Lainé
+ * Copyright (C) 2010-2015 Jeremy Lainé
  * Contact: https://github.com/jlaine/qdjango
  *
  * This file is part of the QDjango Library.
@@ -37,7 +37,7 @@ class QDjangoWherePrivate;
  *
  * \ingroup Database
  */
-class QDJANGO_EXPORT QDjangoWhere
+class QDJANGO_DB_EXPORT QDjangoWhere
 {
 public:
     enum Operation
