@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 Jeremy Lainé
+ * Copyright (C) 2010-2015 Jeremy Lainé
  * Contact: https://github.com/jlaine/qdjango
  *
  * This file is part of the QDjango Library.
@@ -37,7 +37,7 @@ class QDjangoUrlResolver;
  * \ingroup Http
  * \sa QDjangoHttpServer
  */
-class QDJANGO_EXPORT QDjangoFastCgiServer : public QObject
+class QDJANGO_HTTP_EXPORT QDjangoFastCgiServer : public QObject
 {
     Q_OBJECT
 
