@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2010-2014 Jeremy Lainé
+ * Copyright (C) 2010-2015 Jeremy Lainé
  * Contact: https://github.com/jlaine/qdjango
  *
  * This file is part of the QDjango Library.
@@ -19,16 +19,16 @@
 #define QDJANGO_HTTP_P_H
 
 #if defined(QDJANGO_SHARED)
-#  if defined(QDJANGO_BUILD)
-#    define QDJANGO_EXPORT Q_DECL_EXPORT
-#    define QDJANGO_AUTOTEST_EXPORT Q_DECL_EXPORT
+#  if defined(QDJANGO_HTTP_BUILD)
+#    define QDJANGO_HTTP_EXPORT Q_DECL_EXPORT
+#    define QDJANGO_HTTP_AUTOTEST_EXPORT Q_DECL_EXPORT
 #  else
-#    define QDJANGO_EXPORT Q_DECL_IMPORT
-#    define QDJANGO_AUTOTEST_EXPORT Q_DECL_IMPORT
+#    define QDJANGO_HTTP_EXPORT Q_DECL_IMPORT
+#    define QDJANGO_HTTP_AUTOTEST_EXPORT Q_DECL_IMPORT
 #  endif
 #else
-#  define QDJANGO_EXPORT
-#  define QDJANGO_AUTOTEST_EXPORT
+#  define QDJANGO_HTTP_EXPORT
+#  define QDJANGO_HTTP_AUTOTEST_EXPORT
 #endif
 
 #endif
